@@ -26,6 +26,8 @@ from .config_tools import replace_spacecharge_with_PIC
 from .config_tools import configure_orbit_dependent_parameters_for_bb
 from .config_tools import install_spacecharge_frozen
 from .config_tools import full_electroncloud_setup
+from .config_tools import install_beambeam_elements_in_lines
+from .config_tools import configure_beam_beam_elements
 
 from ._version import __version__
 
