@@ -6,10 +6,10 @@
 #ifndef XFIELDS_BEAMBEAM3D_H
 #define XFIELDS_BEAMBEAM3D_H
 
-
 /*gpufun*/
 void synchrobeam_kick(
-        BeamBeamBiGaussian3DData el, const int i_slice,
+        BeamBeamBiGaussian3DData el, LocalParticle *part,
+        const int i_slice,
         double const q0, double const p0c,
         double* x_star,
         double* px_star,
@@ -23,7 +23,6 @@ void synchrobeam_kick(
     const double q0_bb  = scale_strength*BeamBeamBiGaussian3DData_get_other_beam_q0(el);
     const double min_sigma_diff = BeamBeamBiGaussian3DData_get_min_sigma_diff(el);
     const double threshold_singular = BeamBeamBiGaussian3DData_get_threshold_singular(el);
-    
 
     double const Sig_11_0 = BeamBeamBiGaussian3DData_get_slices_other_beam_Sigma_11_star(el, i_slice);
     double const Sig_12_0 = BeamBeamBiGaussian3DData_get_slices_other_beam_Sigma_12_star(el, i_slice);
@@ -38,6 +37,11 @@ void synchrobeam_kick(
 
     double const num_part_slice = BeamBeamBiGaussian3DData_get_slices_other_beam_num_particles(el, i_slice);
 
+    // no kick if not sufficient macroparticles; should be taken care of when slicing
+    if (num_part_slice == 0){
+        return;
+    }
+
     const double x_slice_star = BeamBeamBiGaussian3DData_get_slices_other_beam_x_center_star(el, i_slice);
     const double y_slice_star = BeamBeamBiGaussian3DData_get_slices_other_beam_y_center_star(el, i_slice);
     double const zeta_slice_star = BeamBeamBiGaussian3DData_get_slices_other_beam_zeta_center_star(el, i_slice);
@@ -48,7 +52,13 @@ void synchrobeam_kick(
     const double Ksl = num_part_slice*QELEM*q0_bb*QELEM*q0/(P0 * C_LIGHT);
 
     //Identify the Collision Point (CP)
+    #ifdef XFIELDS_BEAMBEAM3D_FORCE_CP0
+    const double S = 0.0;
+    #else
     const double S = 0.5*(*zeta_star - zeta_slice_star);
+    #endif
+    //printf("S = %f\n", S);
+    //fflush(stdout);
 
     // Propagate sigma matrix
     double Sig_11_hat_star, Sig_33_hat_star, costheta, sintheta;
@@ -103,7 +113,7 @@ void synchrobeam_kick(
     double Gx_hat_star = Ksl*Gx;
     double Gy_hat_star = Ksl*Gy;
 
-    // Move kisks to coupled reference frame
+    // Move kicks to coupled reference frame
     double Fx_star = Fx_hat_star*costheta - Fy_hat_star*sintheta;
     double Fy_star = Fx_hat_star*sintheta + Fy_hat_star*costheta;
 
@@ -111,6 +121,35 @@ void synchrobeam_kick(
     double Fz_star = 0.5*(Fx_hat_star*dS_x_bar_hat_star  + Fy_hat_star*dS_y_bar_hat_star+
                    Gx_hat_star*dS_Sig_11_hat_star + Gy_hat_star*dS_Sig_33_hat_star);
 
+    // emit beamstrahlung photons from single macropart
+    #ifndef XFIELDS_BB3D_NO_BEAMSTR
+    const int64_t flag_beamstrahlung = BeamBeamBiGaussian3DData_get_flag_beamstrahlung(el);
+    if(flag_beamstrahlung==1){
+        double sigma_55_0 = BeamBeamBiGaussian3DData_get_other_beam_sigma_55_star_beamstrahlung(el);  // boosted bunch length
+        LocalParticle_update_pzeta(part, *pzeta_star);  // update energy vars with boost and/or last kick
+        beamstrahlung_avg(part, num_part_slice, sqrt(Sig_11_hat_star), sqrt(Sig_33_hat_star), sigma_55_0);  // slice intensity and RMS slice sizes
+        *pzeta_star = LocalParticle_get_pzeta(part);
+    }
+    else if (flag_beamstrahlung==2){
+        BeamBeamBiGaussian3DRecordData beamstrahlung_record = NULL;
+        BeamstrahlungTableData beamstrahlung_table          = NULL;
+        RecordIndex beamstrahlung_table_index               = NULL;
+        beamstrahlung_record = BeamBeamBiGaussian3DData_getp_internal_record(el, part);
+        if (beamstrahlung_record){
+          beamstrahlung_table       = BeamBeamBiGaussian3DRecordData_getp_beamstrahlungtable(beamstrahlung_record);
+          beamstrahlung_table_index =                      BeamstrahlungTableData_getp__index(beamstrahlung_table);
+        }
+
+        LocalParticle_update_pzeta(part, *pzeta_star);  // update energy vars with boost and/or last kick
+        double const Fr = hypot(Fx_star, Fy_star) * LocalParticle_get_rpp(part); // total kick [1]
+        double const dz = .5*BeamBeamBiGaussian3DData_get_slices_other_beam_zeta_bin_width_star_beamstrahlung(el, i_slice);  // bending radius [m]
+        beamstrahlung(part, beamstrahlung_record, beamstrahlung_table_index, beamstrahlung_table, Fr, dz);
+        *pzeta_star = LocalParticle_get_pzeta(part);  // BS rescales energy vars, so load again before kick
+    }
+    // averaged beamstrahlung using approximate formulas
+    #endif
+
+
     // Apply the kicks (Hirata's synchro-beam)
     *pzeta_star = *pzeta_star + Fz_star+0.5*(
                 Fx_star*(*px_star+0.5*Fx_star)+
@@ -119,8 +158,7 @@ void synchrobeam_kick(
     *px_star = *px_star + Fx_star;
     *y_star = *y_star - S*Fy_star;
     *py_star = *py_star + Fy_star;
-
-    }
+}
 
 
 
@@ -169,7 +207,6 @@ void BeamBeamBiGaussian3D_track_local_particle(BeamBeamBiGaussian3DData el,
         const double q0 = LocalParticle_get_q0(part);
         const double p0c = LocalParticle_get_p0c(part); // eV
 
-
         // Change reference frame
         change_ref_frame_coordinates(
             &x, &px, &y, &py, &zeta, &pzeta,
@@ -179,14 +216,15 @@ void BeamBeamBiGaussian3D_track_local_particle(BeamBeamBiGaussian3DData el,
         // Synchro beam
         for (int i_slice=0; i_slice<N_slices; i_slice++)
         {
-            synchrobeam_kick(el, i_slice, q0, p0c,
+                synchrobeam_kick(
+                             el, part,
+                             i_slice, q0, p0c,
                              &x,
                              &px,
                              &y,
                              &py,
                              &zeta,
                              &pzeta);
-
         }
 
         // Go back to original reference frame and remove dipolar effect
@@ -207,7 +245,6 @@ void BeamBeamBiGaussian3D_track_local_particle(BeamBeamBiGaussian3DData el,
         LocalParticle_update_pzeta(part, pzeta);
 
     //end_per_particle_block
-
 }
 
 
