@@ -77,6 +77,7 @@ class SpaceCharge3D(xt.BeamElement):
 
     _extra_c_sources = [
         _pkg_root.joinpath('headers/constants.h'),
+        _pkg_root.joinpath('headers','particle_states.h'),
         _pkg_root.joinpath('fieldmaps/interpolated_src/linear_interpolators.h'),
         _pkg_root.joinpath('beam_elements/spacecharge_src/spacecharge3d.h'),
     ]
@@ -200,6 +201,7 @@ class SpaceChargeBiGaussian(xt.BeamElement):
         _pkg_root.joinpath('headers/power_n.h'),
         _pkg_root.joinpath('fieldmaps/bigaussian_src/faddeeva.h'),
         _pkg_root.joinpath('fieldmaps/bigaussian_src/bigaussian.h'),
+        _pkg_root.joinpath('fieldmaps/bigaussian_src/bigaussian_fieldmap.h'),
         _pkg_root.joinpath('longitudinal_profiles/qgaussian_src/qgaussian.h'),
         _pkg_root.joinpath('beam_elements/spacecharge_src/spacechargebigaussian.h'),
     ]
