@@ -4,5 +4,5 @@
 # ########################################### #
 
 from .spacecharge_config_tools import *
-from .beambeam_config_tools import configure_orbit_dependent_parameters_for_bb
+from .beambeam_config_tools import *
 from .electroncloud_config_tools import *
\ No newline at end of file
