@@ -1,8 +1,13 @@
+
+#ifndef XFIELDS_CONSTANTS_H
+#define XFIELDS_CONSTANTS_H
+
 // copyright ################################# //
 // This file is part of the Xfields Package.   //
 // Copyright (c) CERN, 2021.                   //
 // ########################################### //
 
+
 #if !defined( C_LIGHT )
     #define   C_LIGHT ( 299792458.0 )
 #endif
@@ -31,6 +36,26 @@
     #define QELEM (1.60217662e-19)
 #endif
 
+#if !defined( MPROTON_GEV )
+    #define MPROTON_GEV (0.93827208816)
+#endif
+
+#if !defined( MELECTRON_GEV )
+    #define MELECTRON_GEV (0.00051099895000)
+#endif
+
+#if !defined( MELECTRON_KG )
+    #define MELECTRON_KG (9.1093837015e-31)
+#endif
+
+#if !defined( ALPHA )
+    #define ALPHA (7.29735257e-3)
+#endif
+
+#if !defined( HBAR_GEVS )
+    #define HBAR_GEVS (6.582119569e-25)
+#endif
+
 #if !defined( TWO_OVER_SQRT_PI )
     #define TWO_OVER_SQRT_PI (1.128379167095512573896158903121545171688101258657997713688171443418)
 #endif
@@ -39,6 +64,12 @@
     #define SQRT_TWO (1.414213562373095048801688724209698078569671875376948073176679738)
 #endif
 
+#if !defined( REDUCED_COMPTON )
+    #define REDUCED_COMPTON (3.8615926796089057e-13)
+#endif
+
 #if !defined( REAL_EPSILON )
     #define REAL_EPSILON 2.22044604925031e-16
 #endif /* !defined( REAL_EPSILON ) */
+
+#endif /* XFIELDS_CONSTANTS_H */
